;;; -*- auto-recompile: t -*-

;; This file is not part of GNU Emacs.
;; 
;; squeak-interaction.el is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; squeak-interaction.el is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Commentary:
;;-------------
;;             interacting with Squeak via TCP/IP

;; last modified April 15, 2005
;; for Emacs 21.1
;;; --------------------------------------------------------------------------------

(defun squeak-connected-somehow-p ()
  (or (squeak-tcpip-process)
      (squeak-connected-via-erman-p)))

(defun squeak-connected-via-erman-p ()
  (and (featurep 'erman)
       (erman-squeak-connected-p)))

(defun squeak-eval (str)
  "Have Squeak evaluate STR as smalltalk code and return the result"
  (if (squeak-connected-via-erman-p)
    (erman-ask-squeak str)
    (squeak-eval-with-return str)))

(defun squeak-do (str)
  "Have Squeak evaluate STR as smalltalk code"
  (if (squeak-connected-via-erman-p)
    (erman-ask-squeak str)
    (condition-case nil
	(squeak-do-through-direct-tcpip str)
      (error (message "No available connection to Squeak")))))

(defun squeak-filename (filename)     ;; est-ce correct ?
  (if (memq system-type '(windows-nt cygwin))
    (mapconcat 'identity (split-string filename "/") "\\")
    filename))

(defun squeak-decode (string)
  (decode-coding-string (base64-decode-string string) 'undecided-mac))

(defun squeak-encode (string)
  (base64-encode-string 
   (encode-coding-string string 'undecided-mac)
   t))

(defun squeak-encode-region (&optional beg end)
  (interactive "r")
  (squeak-encode
   (buffer-substring-no-properties beg end)))

(defun squeak-encode-buffer ()
  (squeak-encode-region (point-min) (point-max)))

;;; --------------------------- End  -----------------------------

(provide 'squeak-interaction)

;;; squeak-interaction.el ends here







